//
//  Win32PlatformInterface.h
//  scummvm
//
//
//

#ifndef __scummvm__Win32PlatformInterface__
#define __scummvm__Win32PlatformInterface__

#include "enhanced/PlatformInterface.h"
#include "backends/platform/sdl/win32/Win32NativeUiInterface.h"

#include <SDL_opengl.h>



class Win32PlatformInterface : public Enhanced::PlatformInterface
{
    
public:
    
	Win32PlatformInterface();
    
    virtual ~Win32PlatformInterface();
    
    virtual Enhanced::NativeUiInterface* getNativeUiInterface();

    /**
     *  Draw a bitmap to the screen.
     * If this is a texture bitmap, it was stored in a HW texture before and should be grabbed from there.
     * If not, the bitmap pixels are stored in the bitmap struct and should be used.
     *
     *  @param bitmap        <#bitmap description#>
     *  @param x             <#x description#>
     *  @param y             <#y description#>
     *  @param width         <#width description#>
     *  @param height        <#height description#>
     *  @param .0            <#.0 description#>
     *  @param customProgram <#customProgram description#>
     */
    virtual void drawOverlayBitmap(Enhanced::OverlayBitmap* bitmap, float x, float y,
                                   float width = 0.0, float height = 0.0, float alpha = 1.0, bool isOnGameArea = true, Enhanced::OverlayShaderType shaderType = Enhanced::OverlayShaderType::NORMAL);
    
	virtual void clearHWTexture();

    /**
     *  Allocate a bitmap in a HW texture (like a sprite sheet) to be drawn later.
     *
     *  @param textureX <#textureX description#>
     *  @param textureY <#textureY description#>
     *  @param h        <#h description#>
     *  @param w        <#w description#>
     */
    virtual void allocateBitmapInTexture(Enhanced::OverlayBitmap* bitmap);
    
    virtual bool IsMT32SupportedDevice();
    
    virtual Common::String getDefaultGraphicSetting();
    
    virtual Common::String getGameFilePath();

    
private:
        
    void initOverlayTextures();

	void initShaders();
	GLuint compileShader(const Common::String &src, GLenum type);
	GLuint linkShaders(GLuint vertex, GLuint fragment);

	GLuint mAreaVertex;
	GLuint mAreaFragment;
	GLuint mAreaProgram;
	GLint mAreaPositionAttribute;
	GLint mAreaProjMatUniform;
	GLint mAreaAlphaFactorUniform;

    
	GLuint* mOverlayGlTextures;

	uint16* mEmptyClearingBuffer;
	uint32* mEmptyClearingBuffer2;


	uint32* mScalerOutputARGB8888;
	uint32* mScalerInputARGB8888;
	uint16* mScalerOutputRGBA5551;


    Win32NativeUiInterface* mUiInterface;
    
};

#endif /* defined(__scummvm__Win32PlatformInterface__) */
